# InlineResponse2008Reactions

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**emoji** | [**InlineResponse2008Emoji**](InlineResponse2008Emoji.md) |  | [optional] 
**reacting_user** | [**InlineResponse2008ReactingUser**](InlineResponse2008ReactingUser.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

